@@ -90,7 +90,8 @@ class Environment(object):
         parser.add_argument('-v', '--version',
                             help='show version info and exit',
                             action='version', version=version_str)
-        parser.add_argument('-p', '--num-cpus', nargs='?',
+        parser.add_argument('-p', '--num-cpus', nargs='?', dest='num_cpus',
+                            type=int,
                             help='specify the number of maximum # CPUs to use',
                             default=multiprocessing.cpu_count())
         vgroup = parser.add_mutually_exclusive_group()
@@ -666,4 +667,4 @@ class AnnounceExitFilter(object):
            record.getMessage().startswith('DECREF'):
             return self._announce_exit
         else:
-            return True
\ No newline at end of file
+            return True
